@@ -18,7 +18,10 @@ class ModuleMirror (Module, FormHelper):
         prefix = "%s!balancer" % (self._prefix)
 
         table = TableProps()
-        e = self.AddPropOptions_Reload (table, "Balancer", prefix, BALANCERS, NOTE_BALANCER)
+        e = self.AddPropOptions_Reload (table, "Balancer", prefix,
+                                        modules_available(BALANCERS), NOTE_BALANCER,
+                                        default_type='host',
+                                        allow_type_change=False)
 
         txt  = "<h2>Load balancing options</h2>"
         txt += self.Indent (str(table) + e)
