@@ -2,6 +2,7 @@ from Form import *
 from Theme import *
 from Entry import *
 from configured import *
+from CherokeeManagement import *
         
 PAGE_BASIC_LAYOUT = """
     <div id="container">
@@ -44,11 +45,31 @@ PAGE_MENU_MENU = """
 </ul>
 
 <br />
+
+<h2>Save Changes</h2>
+
+<div style="padding-top: 2px;">
+ <p>%(menu_save_desc)s</p>
+</div>
+
 <form id="form-apply" action="/apply" method="post">
- <div style="float: center;">
-  <a class="button" href="#" onclick="this.blur(); $('#form-apply').submit(); return false;"><span>Apply</span></a>
+ %(menu_save_dropdown)s
+
+ <div style="float: center; padding-top: 4px;">
+  <a class="button" href="#" onclick="this.blur(); $('#form-apply').submit(); return false;"><span>Save</span></a>
  </div>
 </form>
+
+"""
+
+MENU_SAVE_IS_ALIVE = """
+  <div style="padding-top: 2px;">
+    <select name="restart">
+      <option value="graceful">Graceful restart</option>
+      <option value="hard">Hard restart</option>
+      <option value="no">Do not restart</option>
+    </select>
+  </div>
 """
 
 class Page (WebComponent):
@@ -75,6 +96,13 @@ class PageMenu (Page):
     def __init__ (self, id, cfg):
         Page.__init__ (self, id, cfg)
 
+        manager = cherokee_management_get (cfg)
+        if manager.is_alive():
+            self.AddMacroContent ('menu_save_dropdown', MENU_SAVE_IS_ALIVE)
+            self.AddMacroContent ('menu_save_desc', 'Commit to disk and apply changes to the running server')
+        else:
+            self.AddMacroContent ('menu_save_dropdown', '')
+            self.AddMacroContent ('menu_save_desc', 'Commit all the changes permanently')
+
         self.AddMacroContent ('body', PAGE_MENU_LAYOUT)
         self.AddMacroContent ('menu', PAGE_MENU_MENU)
-
