@@ -452,47 +452,14 @@ cherokee_handler_dirlist_free (cherokee_handler_dirlist_t *dhdl)
 static ret_t
 check_request_finish_with_slash (cherokee_handler_dirlist_t *dhdl)
 {
-	cuint_t                len;
 	cherokee_connection_t *conn = HANDLER_CONN(dhdl);
 
 	if ((cherokee_buffer_is_empty (&conn->request)) ||
 	    (!cherokee_buffer_is_ending (&conn->request, '/'))) 
 	{
-		/* Build the redirection address
-		 */
-		cherokee_buffer_clean (&conn->redirect);
-
-		len = conn->web_directory.len + 
-		      conn->request.len + 
-		      conn->userdir.len + 
-		      conn->host.len + 
-		      sizeof("https://") + 4;
-
-		cherokee_buffer_ensure_size (&conn->redirect, len);
-
-		if (! cherokee_buffer_is_empty (&conn->userdir)) {
-			cherokee_buffer_add_str (&conn->redirect, "/~");
-			cherokee_buffer_add_buffer (&conn->redirect, &conn->userdir);
-		}
-
-		/* In case the connection has a custom Document Root directory,
-		 * it must add the web equivalent directory to the path (web_directory).
-		 */
-		if (cherokee_connection_use_webdir (conn)) {
-			cherokee_buffer_add_buffer (&conn->redirect, &conn->web_directory);
-		}
-		
-		if (! cherokee_buffer_is_empty (&conn->host)) {
-			if (conn->socket.is_tls == TLS)
-				cherokee_buffer_add_str (&conn->redirect, "https://");
-			else
-				cherokee_buffer_add_str (&conn->redirect, "http://");
-
-			cherokee_buffer_add_buffer (&conn->redirect, &conn->host);
-		}
-
-		cherokee_buffer_add_buffer (&conn->redirect, &conn->request);
-		cherokee_buffer_add_str (&conn->redirect, "/");
+		cherokee_buffer_add_str (&conn->request, "/");
+		cherokee_connection_set_redirect (conn, &conn->request);
+		cherokee_buffer_drop_ending (&conn->request, 1);
 		
 		conn->error_code = http_moved_permanently;
 		return ret_error;		
@@ -802,6 +769,7 @@ render_file (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer, file_e
 {
 	ret_t                             ret;
 	cherokee_buffer_t                *vtmp[2];
+	cuint_t                           name_len;
 	cherokee_boolean_t                is_dir;
 	cherokee_boolean_t                is_link  = false;
 	char                             *alt      = NULL;
@@ -830,6 +798,7 @@ render_file (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer, file_e
 	/* Add the icon
 	 */
 	alt = (is_dir) ? "[DIR]" : "[   ]";
+	name_len = strlen(name);
 
 	if (props->show_icons) {
 		if (is_dir) {
@@ -837,7 +806,7 @@ render_file (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer, file_e
 		} else {
 			cherokee_buffer_t name_buf;
 
-			cherokee_buffer_fake (&name_buf, name, strlen(name));
+			cherokee_buffer_fake (&name_buf, name, name_len);
 			ret = cherokee_icons_get_icon (icons, &name_buf, &icon);
 			if (ret != ret_ok)
 				return ret;
@@ -858,7 +827,15 @@ render_file (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer, file_e
 	/* File
 	 */
 	VTMP_SUBSTITUTE_TOKEN ("%file_name%", name);
-	VTMP_SUBSTITUTE_TOKEN ("%file_link%", name);
+
+	if (! is_dir) {
+		VTMP_SUBSTITUTE_TOKEN ("%file_link%", name);
+	} else {
+		cherokee_buffer_clean (tmp);
+		cherokee_buffer_add (tmp, name, name_len);
+		cherokee_buffer_add_str (tmp, "/");
+		VTMP_SUBSTITUTE_TOKEN ("%file_link%", tmp->buf);		
+	}
 
 	/* Date
 	 */
