@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -26,22 +26,30 @@
 #define CHEROKEE_HANDLER_ERROR_REDIR_H
 
 #include "common-internal.h"
+
 #include "handler.h"
 #include "connection.h"
-#include "module_loader.h"
-
+#include "plugin_loader.h"
 
 typedef struct {
-	   cherokee_handler_t handler;
-	   cherokee_buffer_t *content;
+	cherokee_handler_t handler;
+	cherokee_buffer_t *content;
 } cherokee_handler_error_redir_t;
 
-#define ERREDIR_HANDLER(x)  ((cherokee_handler_error_redir_t *)(x))
+typedef struct {
+	cherokee_module_props_t base;
+	cherokee_list_t         errors;
+} cherokee_handler_error_redir_props_t;
 
+#define ERREDIR_HANDLER(x)  ((cherokee_handler_error_redir_t *)(x))
+#define PROP_ERREDIR(x)     ((cherokee_handler_error_redir_props_t *)(x))
+#define HDL_ERREDIR_PROP(x) (PROP_ERREDIR(HANDLER(x)->props))
 
 /* Library init function
  */
-void MODULE_INIT(error_redir) (cherokee_module_loader_t *loader);
-ret_t cherokee_handler_error_redir_new (cherokee_handler_t **hdl, cherokee_connection_t *cnt, cherokee_table_t *properties);
+void  PLUGIN_INIT_NAME(error_redir)          (cherokee_plugin_loader_t *loader);
+
+ret_t cherokee_handler_error_redir_configure (cherokee_config_node_t *conf, cherokee_server_t *srv, cherokee_module_props_t **_props);
+ret_t cherokee_handler_error_redir_new       (cherokee_handler_t **hdl, cherokee_connection_t *cnt, cherokee_module_props_t *props);
 
 #endif /* CHEROKEE_HANDLER_ERROR_REDIR_H */
