@@ -24,6 +24,7 @@
 
 #include "common-internal.h"
 #include "handler_server_info.h"
+#include "bogotime.h"
 
 #ifdef HAVE_SYS_UTSNAME_H
 # include <sys/utsname.h>
@@ -95,7 +96,7 @@
 "<tr class=\"v\"><td>" LICENSE                                                                      CRLF\
 "</td></tr>"                                                                                        CRLF\
 "</table><br />"                                                                                    CRLF\
-"</div></body></html>"                                                                             
+"</div></body></html>"
 
 
 /* Plug-in initialization
@@ -124,7 +125,7 @@ cherokee_handler_server_info_configure (cherokee_config_node_t *conf, cherokee_s
 		CHEROKEE_NEW_STRUCT (n, handler_server_info_props);
 
 		cherokee_module_props_init_base (MODULE_PROPS(n), 
-						 MODULE_PROPS_FREE(props_free));		
+						 MODULE_PROPS_FREE(props_free));
 		n->just_about         = false;
 		n->connection_details = false;
 
@@ -136,13 +137,20 @@ cherokee_handler_server_info_configure (cherokee_config_node_t *conf, cherokee_s
 	cherokee_config_node_foreach (i, conf) {
 		cherokee_config_node_t *subconf = CONFIG_NODE(i);
 
-		if (equal_buf_str (&subconf->key, "just_about")) {
-			props->just_about = atoi(subconf->val.buf);
-		} else if (equal_buf_str (&subconf->key, "connection_details")) {
-			props->connection_details = atoi(subconf->val.buf);
-		} else {
-			PRINT_MSG ("ERROR: Handler file: Unknown key: '%s'\n", subconf->key.buf);
-			return ret_error;
+		if (equal_buf_str (&subconf->key, "type")) {
+			if (equal_buf_str (&subconf->val, "normal")) {
+				
+			} else if (equal_buf_str (&subconf->val, "just_about")) {
+				props->just_about = true;
+				
+			} else if (equal_buf_str (&subconf->val, "connection_details")) {
+				props->connection_details = true;
+
+			} else {
+				PRINT_MSG ("ERROR: Handler server_info: Unknown key value: '%s'\n", 
+					   subconf->val.buf);
+				return ret_error;
+			}
 		}
 	}
 
@@ -181,7 +189,7 @@ table_add_row_int (cherokee_buffer_t *buf, char *name, int value)
 static void
 add_uptime_row (cherokee_buffer_t *buf, cherokee_server_t *srv)
 {
-	unsigned int elapse = srv->bogo_now - srv->start_time;
+	unsigned int elapse = cherokee_bogonow_now - srv->start_time;
 	unsigned int days;
 	unsigned int hours;
 	unsigned int mins;
@@ -194,7 +202,7 @@ add_uptime_row (cherokee_buffer_t *buf, cherokee_server_t *srv)
 
 	hours = elapse / (60*60);
 	elapse %= (60*60);
-	
+
 	mins = elapse / 60;
 	elapse %= 60;
 
@@ -210,7 +218,7 @@ add_uptime_row (cherokee_buffer_t *buf, cherokee_server_t *srv)
 	} else {
 		cherokee_buffer_add_va (tmp, "%d Seconds", elapse);
 	}
-	
+
 	table_add_row_str (buf, "Uptime", tmp->buf);
 	cherokee_buffer_free (tmp);
 }
@@ -218,16 +226,19 @@ add_uptime_row (cherokee_buffer_t *buf, cherokee_server_t *srv)
 static void
 add_data_sent_row (cherokee_buffer_t *buf, cherokee_server_t *srv)
 {
-	size_t rx, tx;
-	char tmp[8];
+	size_t            rx, tx;
+	cherokee_buffer_t tmp = CHEROKEE_BUF_INIT;
 
 	cherokee_server_get_total_traffic (srv, &rx, &tx);
-	
-	cherokee_strfsize (tx, tmp);
-	table_add_row_str (buf, "Data sent", tmp);
 
-	cherokee_strfsize (rx, tmp);
-	table_add_row_str (buf, "Data received", tmp);
+	cherokee_buffer_add_fsize (&tmp, tx);
+	table_add_row_buf (buf, "Data sent", &tmp);
+
+	cherokee_buffer_clean (&tmp);
+	cherokee_buffer_add_fsize (&tmp, rx);
+	table_add_row_buf (buf, "Data received", &tmp);
+
+	cherokee_buffer_mrproper (&tmp);
 }
 
 static void
@@ -271,7 +282,7 @@ build_connections_table_content (cherokee_buffer_t *buf, cherokee_server_t *srv)
 	cuint_t conns_num = 0;
 	cuint_t active    = 0;
 	cuint_t reusable  = 0;
-	
+
 	cherokee_server_get_conns_num (srv, &conns_num);
 	cherokee_server_get_active_conns (srv, &active);
 	cherokee_server_get_reusable_conns (srv, &reusable);
@@ -370,8 +381,8 @@ build_icons_table_content (cherokee_buffer_t *buf, cherokee_server_t *srv)
 static void
 build_connection_details_content (cherokee_buffer_t *buf, cherokee_list_t *infos) 
 {
-	char tmp[8];
-	cherokee_list_t *i, *j;
+	cherokee_list_t   *i, *j;
+	cherokee_buffer_t tmp    = CHEROKEE_BUF_INIT;
 
 	list_for_each_safe (i, j, infos) {
 		cherokee_connection_info_t *info = CONN_INFO(i);
@@ -381,16 +392,19 @@ build_connection_details_content (cherokee_buffer_t *buf, cherokee_list_t *infos
 		table_add_row_buf (buf, "Phase",         &info->phase);
 		table_add_row_buf (buf, "Request",       &info->request);
 		table_add_row_buf (buf, "Handler",       &info->handler);
+		
+		cherokee_buffer_clean (&tmp);
+		cherokee_buffer_add_fsize (&tmp, strtoll(info->rx.buf, (char**)NULL, 10));
+		table_add_row_buf (buf, "Info sent", &tmp);
 
-		cherokee_strfsize (strtoll(info->rx.buf, (char**)NULL, 10), tmp);
-		table_add_row_str (buf, "Info sent", tmp);
-
-		cherokee_strfsize (strtoll(info->tx.buf, (char**)NULL, 10), tmp);
-		table_add_row_str (buf, "Info received", tmp);
+		cherokee_buffer_clean (&tmp);
+		cherokee_buffer_add_fsize (&tmp, strtoll(info->tx.buf, (char**)NULL, 10));
+		table_add_row_buf (buf, "Info received", &tmp);
 
 		if (! cherokee_buffer_is_empty (&info->total_size)) {
-			cherokee_strfsize (strtoll(info->total_size.buf, (char**)NULL, 10), tmp);
-			table_add_row_str (buf, "Total Size", tmp);
+			cherokee_buffer_clean (&tmp);
+			cherokee_buffer_add_fsize (&tmp, strtoll(info->total_size.buf, (char**)NULL, 10));
+			table_add_row_buf (buf, "Total Size", &tmp);
 		}
 
 		if (! cherokee_buffer_is_empty (&info->percent)) {
@@ -404,6 +418,8 @@ build_connection_details_content (cherokee_buffer_t *buf, cherokee_list_t *infos
 		table_add_row_str (buf, "", "");
 		cherokee_connection_info_free (info);
 	}
+
+	cherokee_buffer_mrproper (&tmp);
 }
 
 
