@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2008 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -22,36 +22,31 @@
  * USA
  */
 
-#ifndef __CHEROKEE_MACHING_LIST_H__
-#define __CHEROKEE_MACHING_LIST_H__
+#ifndef CHEROKEE_MACHING_LIST_H
+#define CHEROKEE_MACHING_LIST_H
 
 #include "common.h"
 #include "list.h"
-
+#include "config_node.h"
 
 typedef enum {
-	   default_allow,
-	   default_deny,
-	   deny_allow,
-	   allow_deny
+	default_allow,
+	default_deny,
+	deny_allow,
+	allow_deny
 } cherokee_matching_t;
 
 
 typedef struct {
-	   struct list_head   list;
-	   char              *string;
+	cherokee_list_t     list;
+	char               *string;
 } cherokee_matching_list_entry_t;
 
 
 typedef struct {
-
-	   /* Lists
-	    */
-	   list_t list_allow;
-	   list_t list_deny;
-
-	   cherokee_matching_t type;
-
+	cherokee_list_t     list_allow;
+	cherokee_list_t     list_deny;
+	cherokee_matching_t type;
 } cherokee_matching_list_t;
 
 #define MLIST(x)       ((cherokee_matching_list_t *)(x))
@@ -64,7 +59,8 @@ ret_t cherokee_matching_list_free      (cherokee_matching_list_t  *mlist);
 ret_t cherokee_matching_list_add_allow (cherokee_matching_list_t *mlist, const char *item);
 ret_t cherokee_matching_list_add_deny  (cherokee_matching_list_t *mlist, const char *item);
 
+ret_t cherokee_matching_list_configure (cherokee_matching_list_t *mlist, cherokee_config_node_t *config);
 ret_t cherokee_matching_list_set_type  (cherokee_matching_list_t *mlist, cherokee_matching_t type);
 int   cherokee_matching_list_match     (cherokee_matching_list_t *mlist, char *match);
 
-#endif /* __CHEROKEE_MACHING_LIST_H__ */
+#endif /* CHEROKEE_MACHING_LIST_H */
