@@ -32,6 +32,7 @@
 #include <cherokee/common.h>
 #include <cherokee/avl.h>
 #include <cherokee/trace.h>
+#include <cherokee/plugin_loader.h>
 
 #ifdef HAVE_NETINET_IN_H
 # include <netinet/in.h>
@@ -85,9 +86,9 @@ char   *cherokee_strerror_r         (int err, char *buf, size_t bufsize);
 int     cherokee_isbigendian        (void);
 char   *cherokee_min_str            (char *s1, char *s2);
 char   *cherokee_max_str            (char *s1, char *s2);
-char   *cherokee_strfsize           (unsigned long long size, char *buf);
 size_t  cherokee_strlcat            (char *dst, const char *src, size_t siz);
 int     cherokee_estimate_va_length (char *format, va_list ap);
+ret_t   cherokee_fix_dirpath        (cherokee_buffer_t *buf);
 
 /* Time management functions
  */
@@ -103,20 +104,24 @@ ret_t cherokee_syslog        (int priority, cherokee_buffer_t *buf);
 ret_t cherokee_getpwnam      (const char *name, struct passwd *pwbuf, char *buf, size_t buflen);
 ret_t cherokee_getgrnam      (const char *name, struct group *pwbuf, char *buf, size_t buflen);
 ret_t cherokee_mkstemp       (cherokee_buffer_t *buffer, int *fd);
+ret_t cherokee_mkdir_p       (cherokee_buffer_t *path);
 
 /* Misc
  */
-ret_t cherokee_fd_set_nonblocking (int fd);
+ret_t cherokee_fd_set_nonblocking (int fd, cherokee_boolean_t enable);
+ret_t cherokee_fd_set_nodelay     (int fd, cherokee_boolean_t enable);
+ret_t cherokee_fd_set_closexec    (int fd);
+ret_t cherokee_fd_close           (int fd);
 
 ret_t cherokee_sys_fdlimit_get (cuint_t *limit);
 ret_t cherokee_sys_fdlimit_set (cuint_t  limit);
-ret_t cherokee_close_fd        (cint_t fd);
 ret_t cherokee_get_shell       (const char **shell, const char **binary);
+void  cherokee_print_wrapped   (cherokee_buffer_t *buffer);
 
 /* Debug
  */
-void  cherokee_trace       (const char *entry, const char *file, int line, const char *func, const char *fmt, ...);
-void  cherokee_print_errno (int error, char *format, ...);
+void  cherokee_trace           (const char *entry, const char *file, int line, const char *func, const char *fmt, ...);
+void  cherokee_print_errno     (int error, char *format, ...);
 
 /* Path walking
  */
