@@ -1,13 +1,13 @@
 from base import *
 
 CONF = """
-vserver!default!rule!410!match = directory
-vserver!default!rule!410!match!directory = /auth3
-vserver!default!rule!410!match!final = 0
-vserver!default!rule!410!auth = plain
-vserver!default!rule!410!auth!methods = basic
-vserver!default!rule!410!auth!realm = Test
-vserver!default!rule!410!auth!passwdfile = %s
+vserver!1!rule!410!match = directory
+vserver!1!rule!410!match!directory = /auth3
+vserver!1!rule!410!match!final = 0
+vserver!1!rule!410!auth = plain
+vserver!1!rule!410!auth!methods = basic
+vserver!1!rule!410!auth!realm = Test
+vserver!1!rule!410!auth!passwdfile = %s
 """
 
 class Test (TestBase):
