@@ -1,10 +1,10 @@
 from base import *
 
 CONF = """
-vserver!default!rule!460!match = directory
-vserver!default!rule!460!match!directory = /redir46
-vserver!default!rule!460!handler = redir
-vserver!default!rule!460!handler!url = http://www.cherokee-project.com
+vserver!1!rule!460!match = directory
+vserver!1!rule!460!match!directory = /redir46
+vserver!1!rule!460!handler = redir
+vserver!1!rule!460!handler!url = http://www.cherokee-project.com
 """
 
 class Test (TestBase):
