@@ -6,12 +6,12 @@ USER="cherokeeqa"
 PASS="cherokeeqa"
 
 CONF = """
-vserver!default!rule!610!match = directory
-vserver!default!rule!610!match!directory = /privpam
-vserver!default!rule!610!match!final = 0
-vserver!default!rule!610!auth = pam
-vserver!default!rule!610!auth!methods = basic
-vserver!default!rule!610!auth!realm = Test PAM
+vserver!1!rule!610!match = directory
+vserver!1!rule!610!match!directory = /privpam
+vserver!1!rule!610!match!final = 0
+vserver!1!rule!610!auth = pam
+vserver!1!rule!610!auth!methods = basic
+vserver!1!rule!610!auth!realm = Test PAM
 """
 
 
@@ -40,12 +40,11 @@ class Test (TestBase):
         if os.getuid() != 0:
             return False
 
-        try:
-            # Check that pam module was compiled
-            pams = filter(lambda x: "pam" in x, os.listdir(CHEROKEE_MODS))
-            if len(pams) < 1:
-                return False
+        # Check that pam module was compiled
+        if not cherokee_has_plugin("pam"):
+            return False
 
+        try:
             # Read the /etc/passwd file
             f = open ("/etc/passwd", "r")
             pwuser = filter(lambda x: x.find(USER) == 0, f.readlines())
