@@ -4,14 +4,14 @@ REQUIRED  = "This is working! :-)"
 FORBIDDEN = "It shouldn't appear in the text"
 
 CONF = """
-vserver!default!rule!800!match = directory
-vserver!default!rule!800!match!directory = /extension2
-vserver!default!rule!800!handler = file
+vserver!1!rule!800!match = directory
+vserver!1!rule!800!match!directory = /extension2
+vserver!1!rule!800!handler = file
 
-vserver!default!rule!801!match = extensions
-vserver!default!rule!801!match!extensions = abc,def,ghi
-vserver!default!rule!801!handler = phpcgi
-vserver!default!rule!801!handler!interpreter = %s
+vserver!1!rule!801!match = extensions
+vserver!1!rule!801!match!extensions = abc,def,ghi
+vserver!1!rule!801!handler = phpcgi
+vserver!1!rule!801!handler!interpreter = %s
 """
 
 class Test (TestBase):
