@@ -4,10 +4,10 @@ from base import *
 PATH_INFO   = "/this_is_the/path_info"
 
 CONF = """
-vserver!default!rule!1040!match = directory
-vserver!default!rule!1040!match!directory = /alias_and_pathinfo
-vserver!default!rule!1040!handler = cgi
-vserver!default!rule!1040!handler!script_alias = %s
+vserver!1!rule!1040!match = directory
+vserver!1!rule!1040!match!directory = /alias_and_pathinfo
+vserver!1!rule!1040!handler = cgi
+vserver!1!rule!1040!handler!script_alias = %s
 """
 
 class Test (TestBase):
