@@ -4,11 +4,11 @@ MAGIC = "I_bet_Cherokee_is_better"
 URL   = "http://www.example.com"
 
 CONF = """
-vserver!default!rule!1180!match = request
-vserver!default!rule!1180!match!request = ^/req_redir_compact1/(.*)/
-vserver!default!rule!1180!handler = redir
-vserver!default!rule!1180!handler!rewrite!1!show = 1
-vserver!default!rule!1180!handler!rewrite!1!substring = %s/$1
+vserver!1!rule!1180!match = request
+vserver!1!rule!1180!match!request = ^/req_redir_compact1/(.*)/
+vserver!1!rule!1180!handler = redir
+vserver!1!rule!1180!handler!rewrite!1!show = 1
+vserver!1!rule!1180!handler!rewrite!1!substring = %s/$1
 """
 
 class Test (TestBase):
