@@ -18,13 +18,13 @@ SCGIServer(TestHandler, port=%d).serve_forever()
 """ % (PORT)
 
 CONF = """
-vserver!default!rule!1270!match = directory
-vserver!default!rule!1270!match!directory = <dir>
-vserver!default!rule!1270!handler = scgi
-vserver!default!rule!1270!handler!balancer = round_robin
-vserver!default!rule!1270!handler!balancer!type = interpreter
-vserver!default!rule!1270!handler!balancer!local_scgi2!host = localhost:%d
-vserver!default!rule!1270!handler!balancer!local_scgi2!interpreter = %s %s
+vserver!1!rule!1270!match = directory
+vserver!1!rule!1270!match!directory = <dir>
+vserver!1!rule!1270!handler = scgi
+vserver!1!rule!1270!handler!balancer = round_robin
+vserver!1!rule!1270!handler!balancer!type = interpreter
+vserver!1!rule!1270!handler!balancer!local_scgi2!host = localhost:%d
+vserver!1!rule!1270!handler!balancer!local_scgi2!interpreter = %s %s
 """
 
 
