@@ -10,10 +10,10 @@ OFFSET2 = 40
 DIR     = "range_both_100b_noio"
 
 CONF = """
-vserver!default!rule!1470!match = directory
-vserver!default!rule!1470!match!directory = <dir>
-vserver!default!rule!1470!handler = file
-vserver!default!rule!1470!handler!iocache = 0
+vserver!1!rule!1470!match = directory
+vserver!1!rule!1470!match!directory = <dir>
+vserver!1!rule!1470!handler = file
+vserver!1!rule!1470!handler!iocache = 0
 """
 
 
