@@ -6,10 +6,10 @@ from util import *
 DIR = "common_pathinfo_2"
 
 CONF = """
-vserver!default!rule!1500!match = directory
-vserver!default!rule!1500!match!directory = <dir>
-vserver!default!rule!1500!handler = common
-vserver!default!rule!1500!handler!allow_pathinfo = 0
+vserver!1!rule!1500!match = directory
+vserver!1!rule!1500!match!directory = <dir>
+vserver!1!rule!1500!handler = common
+vserver!1!rule!1500!handler!allow_pathinfo = 0
 """
 
 class Test (TestBase):
